@@ -11,12 +11,20 @@ def safe_json_dumps(obj):
         pass
     return obj
 
-async def async_make_request(url, payload, headers=None):
-    async with httpx.AsyncClient(timeout=1000) as client:
-        response = await client.post(url, data=safe_json_dumps(payload), headers=headers)
-        response.raise_for_status()  # Raise exception for non-2xx status codes
-        return response  # or just return response if you want the full object
 
+async def async_make_request(url, payload, headers=None):
+    # Log the payload and headers for debugging
+    logging.debug(f"Making async POST request to {url} with payload: {payload} and headers: {headers}")
+    
+    async with httpx.AsyncClient(timeout=1000) as client:
+        # Use json=payload instead of data= to ensure correct encoding and headers
+        response = await client.post(url, json=payload, headers=headers)
+        
+        # Log the response status and content
+        logging.debug(f"Received response: {response.status_code} - {response.text}")
+        
+        response.raise_for_status()  # Raise exception for non-2xx status codes
+        return response  # Return the full response if needed
 def get_kwargs_bools(key, bools, **kwargs):
     bools[key] = kwargs.get(key)
     if key in kwargs:
